#
# KXmms gdesklets Control
# Copyright 2005 - Andrea Briganti <kbytesys@tin.it>
# Version 0.1
#
# This Control was inspired by the Stefano Mozzi's CornerXMMS Sensor
#
# This Control is released under GPL 2.0 Licence.

from libdesklets.controls import Control

import xmms.control
import string
import os
import time

from IKXmms import IKXmms

class KXmms(Control, IKXmms):
	def __init__(self):
		Control.__init__(self)
		self._curtitle = ""
		self._isRunning = 0
		self._curtime = 0
		self._fill = 0
		self._ispaused = 0
		self._isplaying = 0
		self._isplwin = 0
		self._iseqwin = 0
		self._ismainwin = 0
		self._isrepeat = 0
		self._israndom = 0

		self._add_timer( 500, self.__timer )

	def __timer(self):
		_m_old_value = self._isRunning
		self.__running()
		if(self._isRunning != _m_old_value):
			self._update("running")

		if(self._isRunning == True):
			_m_old_value = self._curtitle
			self.__title()
			if(self._curtitle != _m_old_value):
				self._update("title")

			_m_old_value = self._curtime
			self.__curtime()
			if(self._curtime != _m_old_value):
				self._update("curtime")

			_m_old_value = self._fill
			self.__fill()
			if(self._fill != _m_old_value):
				self._update("fill")

			_m_old_value = self._ispaused
			self.__ispaused()
			if(self._ispaused != _m_old_value):
				self._update("ispaused")

			_m_old_value = self._isplaying
			self.__isplaying()
			if(self._isplaying != _m_old_value):
				self._update("isplaying")

			_m_old_value = self._isplwin
			self.__isplwin()
			if(self._isplwin != _m_old_value):
				self._update("isplwin")

			_m_old_value = self._iseqwin
			self.__iseqwin()
			if(self._iseqwin != _m_old_value):
				self._update("iseqwin")

			_m_old_value = self._ismainwin
			self.__ismainwin()
			if(self._ismainwin != _m_old_value):
				self._update("ismainwin")

			_m_old_value = self._isrepeat
			self.__isrepeat()
			if(self._isrepeat != _m_old_value):
				self._update("isrepeat")

			_m_old_value = self._israndom
			self.__israndom()
			if(self._israndom != _m_old_value):
				self._update("israndom")



		return True

#	def __action(self, action, value):
#		if (value):
#                       print value


	def __action(self, command):
		if type(command) is tuple:
			(action, value) = command
		else:
			action = command
			
		if (action == "jumpto"):
			tj = float(self.__length()) * value / float(100)
			xmms.control.jump_to_time(tj)
		elif (action == "stop"):
			xmms.control.stop()

		elif (action == "play"):
			xmms.control.play()

		elif (action == "next"):
			xmms.control.playlist_next()

		elif (action == "prev"):
			xmms.control.playlist_prev()

		elif (action == "pause"):
			xmms.control.pause()

		elif (action == "eject"):
			xmms.control.eject()

		elif (action == "plwin"):
			xmms.control.pl_win_toggle(not(xmms.is_pl_win()))

		elif (action == "eqwin"):
			xmms.control.eq_win_toggle(not(xmms.is_eq_win()))

		elif (action == "mainwin"):
			xmms.control.main_win_toggle(not(xmms.is_main_win()))

		elif (action == "prefs"):
			xmms.control.show_prefs_box()

		elif (action == "reptog"):
			xmms.control.toggle_repeat()

		elif (action == "rndtog"):
			xmms.control.toggle_shuffle()

		elif (action == "quit"):
			if (xmms.control.is_running()):
				xmms.control.quit()
			else:
				os.system("cd ~ && xmms & disown")

		elif (action == "turnin"):
			if (xmms.control.is_running()):
				xmms.control.enqueue_and_play(value)
			else:
				os.system("cd ~ && xmms & disown")
				time.sleep(1)
				xmms.control.enqueue_and_play(value)

	def __title(self):
		self._curtitle = xmms.control.get_playlist_title(xmms.control.get_playlist_pos())
#		return self._curtitle
		return xmms.control.get_playlist_title(xmms.control.get_playlist_pos())

	def __running(self):
		if xmms.control.is_running() == 1:
			self._isRunning = True
		else:
			self._isRunning = False

		return self._isRunning

	def __bitrate(self):
		bitrate, freq, nch = xmms.control.get_info()
		return (bitrate, freq, nch)

	def __curtime(self):
		try:
			self._curtime = xmms.get_output_time()
		except:
			self._curtime = 0
			
		return self._curtime

	def __fill(self):
		length = self.__length()
		if(length != 0):
			self._fill = float(self._curtime) / float(length) * 100
		else:
			self._fill = 0
		return self._fill

        def __length(self):
                try:
                        return xmms.control.get_playlist_time(xmms.control.get_playlist_pos())
                except:
                        return 0
                return 0


	def __ispaused(self):
		self._ispaused = xmms.control.is_paused()
		return self._ispaused

	def __isplaying(self):
		self._isplaying = xmms.control.is_playing()
		return self._isplaying

	def __isplwin(self):
		self._isplwin = xmms.control.is_pl_win()
		return self._isplwin

	def __iseqwin(self):
		self._iseqwin = xmms.control.is_eq_win()
		return self._iseqwin

	def __ismainwin(self):
		self._ismainwin = xmms.control.is_main_win()
		return self._ismainwin

	def __isrepeat(self):
		self._isrepeat = xmms.control.is_repeat()
		return self._isrepeat

	def __israndom(self):
		self._israndom = xmms.control.is_shuffle()
		return self._israndom

	action = property(fset = __action)
	title = property(fget = __title)
	running = property(fget = __running)
	bitrate = property(fget = __bitrate)
	length = property(fget = __length)
	curtime = property(fget = __curtime)
	fill = property(fget = __fill)
	ispaused = property(fget = __ispaused)
	isplaying = property(fget = __isplaying)
	isplwin = property(fget = __isplwin)
	iseqwin = property(fget = __iseqwin)
	ismainwin = property(fget = __ismainwin)
	isrepeat = property(fget = __isrepeat)
	israndom = property(fget = __israndom)

def get_class(): return KXmms
